/*
 * main.c
 *
 * RF430CL331H Host Example Project
 *
 * Copyright (C) 2015 Texas Instruments Incorporated - http://www.ti.com/
 *
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/


//******************************************************************************
//   RF430CL331H Boosterpack
//
//   Description: 	Demonstrates the NFC NDEF large message read and write
//
//   Texas Instruments Inc.
//   February 2014
//******************************************************************************

// Basic MSP430 and driverLib #includes
#include "msp430.h"
#include "driverlib/MSP430F5xx_6xx/pmm.h"

// Application #includes
//#include "BCUart.h"           // Include the backchannel UART "library"
#include "hal.h"              // Modify hal.h to select your hardware
#include <stdint.h>
#include "RF430_example.h"
#include "Request_Processor.h"
#include "RF430_Comm.h"

uint8_t into_fired = 0;

//BUG FIXES: LOOPING, INIT AND NO WAIT TIME EXTENSION REQUEST
uint8_t errata_fixes[] =	 {  0xB2, 0xF0, 0xFF, 0xFB, 0x00, 0x07, 0xB2, 0xF0, 0xFF, 0xFD, 0x00, 0x07, 0xA2, 0xC3, 0x00, 0x07,
								0x08, 0x3C, 0xB2, 0xF0, 0xFF, 0xFB, 0x00, 0x07, 0xB2, 0xF0, 0xFF, 0xFD, 0x00, 0x07, 0xA2, 0xC3,
								0x00, 0x07, 0xB2, 0xB0, 0x04, 0x04, 0x00, 0x07, 0xF4, 0x23, 0x30, 0x41, 0x0F, 0x12, 0x0E, 0x12,
								0xB2, 0xB0, 0x00, 0x01, 0x00, 0x07, 0x08, 0x24, 0x3E, 0x40, 0x1D, 0x00, 0x1F, 0x42, 0xB2, 0x2A,
								0x6E, 0x9F, 0x02, 0x20, 0x92, 0x43, 0x2E, 0x2A, 0x3E, 0x41, 0x3F, 0x41, 0x30, 0x41};


/**************************************************************************************************************************************************
*   main
***************************************************************************************************************************************************
*
* Brief : Main function
*
* Param[in] :   None
*
* Param[out]:   None
*
* Return :      None
**************************************************************************************************************************************************/
void main(void)
{
	volatile uint16_t test = 0;
	uint16_t flags = 0;
	WDTCTL = WDTPW + WDTHOLD;		// Halt the watchdog

    // MSP430 USB requires a Vcore setting of at least 2.  2 is high enough
	// for 8MHz MCLK, below.
    PMM_setVCore(PMM_CORE_LEVEL_2);

    initPorts();           // Config all the GPIOS for low-power (output low)
    initClocks(8000000);   // Config clocks. MCLK=SMCLK=FLL=8MHz; ACLK=REFO=32kHz

    // Configure I2C
	PORT_I2C_SEL |= (SCL + SDA);
	UCB0CTL1 = UCSWRST;	            			// Software reset enabled
	UCB0CTL0 |= UCMODE_3  + UCMST + UCSYNC;		// I2C mode, Master mode, sync, transmitter
	UCB0CTL1 = UCSSEL_2 + UCSWRST;              // SMCLK = 8MHz
	UCB0BRW = 20; 								// Baudrate = SMLK/20 = 400kHz
	UCB0I2CSA  = 0x0018;						// slave address - determined by pins E0, E1, and E2 on the RF430CL331H
//	UCB0I2CSA  = 0x001E;						// slave address - determined by pins E0, E1, and E2 on the RF430CL331H
	UCB0CTL1  &= ~UCSWRST;
	UCB0IE |= UCTXIE + UCRXIE + UCSTPIE + UCNACKIE;

	//configure pin for INTO interrupts
	PORT_INTO_DIR &= ~INTO; 		//input
	PORT_INTO_OUT |= INTO; 			//output high for pullup
	PORT_INTO_REN |= INTO; 			//internal pullup resistor
	PORT_INTO_IFG &= ~INTO; 		//clear interrupt flag
	PORT_INTO_IES |= INTO; 			//fire interrupt on high-to-low transition since INTO is setup active low

	//Configure pins for Reset and send the reset signal to the RF430CL331H
    PORT_RST_DIR |= RST;		//Reset signal to RF430
    PORT_RST_OUT |= RST;		//Deassert Reset signal
    __delay_cycles(1000000); 		//leave time for the RF430CL33H to see signal
    PORT_RST_OUT &= ~RST;		//Reset signal to RF430
    __delay_cycles(1000000); 		//leave time for the RF430CL33H to see signal
    PORT_RST_OUT |= RST;		//Reset signal to RF430
    __delay_cycles(1000000); 		//leave time for the RF430CL33H to get itself initialized

    //Setup the I2C ready input
    I2C_READY_DIR &= ~I2C_READY_PIN;	//Set I2C_READY singal to input on MSP430

    __enable_interrupt();  // Enable interrupts globally

    while(!(Read_Register(STATUS_REG) & READY)); //wait until READY bit has been set

	/****************************************************************************/
    /* Errata Fixes: "Looping", unresponsive RF, and no SWXT                    */
    /****************************************************************************/
    {
		//Please implement this fix as given in this block.  It is important that
		//no line be removed or changed.

    	//Enter test mode to set the maximum data rate that RF430 reports to mobile/reader
		//Currently sets to 106kbps with a 0 setting
    	//Also loads some bug fixes.

		Write_Register(0xFFE0, 0x004E);
		Write_Register(0xFFFE, 0x0080);
		Write_Continuous (0x2AD0, (uint8_t *) &errata_fixes, sizeof(errata_fixes));		//write the patch to memory
		Write_Register(0x2A90, 0x2AFC); 	            // looping fix
		Write_Register(0x2AAE, 0x2AD0); 	            // wait time extension fix
		Write_Register(0x2A66, 0x0000); 		        // fix by init

		//RF Data rate settings
		// C4 = 847kbps , A2 = 424kbps, 91 = 212kbps, 00 = 106kbps (DEFAULT)
		//Write_Register(0x2ABA, 0x00C4);  				// C4 = 847kbps
		//Write_Register(0x2ABA, 0x00A2);  				// A2 = 424kbps
		//Write_Register(0x2ABA, 0x0091);  				// 91 = 212kbps
		Write_Register(0x2ABA, 0x0000);  				// 00 = 106kbps (DEFAULT SETTING) so this line is optional

		Write_Register(0x27B8, 0);
		Write_Register(0xFFE0, 0);
		//Upon exit of this block, the control register is set to 0x0
    }

    /****************************************************************************/
    /* Configure RF430CL330H for Typical Usage Scenario                         */
    /****************************************************************************/

    AppInit();

	// DATA_TRANSACTION_INT_ENABLE - general NDEF interrupt - should always be enabled
	// EXTRA_DATA_IN_INT_ENABLE - enables the read pre-fetch option, code in this project can handle this if enabled,
	//								speeds up read speeds 10-30% depending on mobile
	// FIELD_REMOVED_INT_ENABLE - sends an interrupt if the RF430 has been removed from the RF field
	// GENERIC_ERROR_INT_ENABLE - this will send an interrupt in some cases of RF430 resets

	// Write_Register(INT_ENABLE_REG, DATA_TRANSACTION_INT_ENABLE + EXTRA_DATA_IN_INT_ENABLE  + FIELD_REMOVED_INT_ENABLE + GENERIC_ERROR_INT_ENABLE);
    Write_Register(INT_ENABLE_REG, DATA_TRANSACTION_INT_ENABLE + FIELD_REMOVED_INT_ENABLE + GENERIC_ERROR_INT_ENABLE);

    //AUTO_ACK_ON_WRITE - automatically acks UpdateBinary requests - speeds up write speeds 10-30% depending on mobile

    Write_Register(CONTROL_REG,  /* AUTO_ACK_ON_WRITE + */ INT_ENABLE + INTO_DRIVE + RF_ENABLE);

    // sets the command timeouts, generally should stay at these settings
    Write_Register(SWTX_INDEX, 0x3B);  // maximum allowable wait time extension request

	//prepare interrupt detection
	PORT_INTO_IFG &= ~INTO; // clear any pending flags
	PORT_INTO_IE |= INTO;	// enable interrupt

	while (1)
    {
    	__bis_SR_register(LPM0_bits + GIE); //go to low power mode and enable interrupts. Here we are waiting for an RF read or write
    	__no_operation();

    	//device has woken up, check status
    	if(into_fired)
    	{
			flags = Read_Register(INT_FLAG_REG); //read the flag register to check if a read or write occurred
    		do
    		{
				if (flags)
				{
					ServiceInterrupt(flags);
				}
    			//interrupts may have occured while servicing a prior interrupt, check again to make sure all are serviced
				flags = Read_Register(INT_FLAG_REG); //read the flag register to check if a read or write occurred
    		}while(flags);

    		//re-enable INTO
    		PORT_INTO_IFG &= ~INTO;
    		PORT_INTO_IE |= INTO;

			__no_operation();
    	}
    	flags = 0;
    	into_fired = 0; //we have serviced INTO

    }
}

/**************************************************************************************************************************************************
*   PORT2_ISR
***************************************************************************************************************************************************
*
* Brief : Handles the INTO interrupt detection
*
* Param[in] :   None
*
* Param[out]:   None
*
* Return :      None
**************************************************************************************************************************************************/
#pragma vector=PORT2_VECTOR
__interrupt void PORT2_ISR(void)
{
	//INTO interrupt fired
	if(PORT_INTO_IFG & INTO)
	{

		into_fired = 1;

		PORT_INTO_IE &= ~INTO; //disable INTO
		PORT_INTO_IFG &= ~INTO; //clear interrupt flag

		__bic_SR_register_on_exit(LPM3_bits + GIE); //wake up to handle INTO
	}
}

